summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/tools/lcgenerator.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/tools/lcgenerator.h')
-rw-r--r--kstars/kstars/tools/lcgenerator.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kstars/kstars/tools/lcgenerator.h b/kstars/kstars/tools/lcgenerator.h
index 4e8e055c..6d570060 100644
--- a/kstars/kstars/tools/lcgenerator.h
+++ b/kstars/kstars/tools/lcgenerator.h
@@ -54,12 +54,13 @@ struct VariableStarInfo
class LCGenerator : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**Constructor
*@p parent pointer to the parent widget
*/
- LCGenerator( TQWidget* parent = 0);
+ LCGenerator( TQWidget* tqparent = 0);
/**Destructor */
~LCGenerator();
@@ -54,12 +54,13 @@ struct VariableStarInfo
public:
/**Constructor
- *@p parent pointer to the parent widget
+ *@p tqparent pointer to the tqparent widget
*/